<?php
/** * @description This php script contains all the stuff to backup interactive activities
 *  * @authors Patricia Alves Rodrigues and Leônidas O. Brandão
 *  * @version $Id: backuplib.php$ v 1.0 2010/10/23$
 *  * @package iAssign: Intective Assignments
 *  * @last modification date 2010/12/21
 *  *
 *  * iMatica - iMath (http://www.matematica.br)
 *  * Computer Science Dep. of IME-USP (Brazil)
 *  * */

    //This is the "graphical" structure of the ia mod:
    //
    //                ia
    //           (CL,pk->id)
    //                |
    //                |
    //                |
    //            ia_assigns
    //         (UL,pk->id,fk->ia)
    //                |
    //                |
    //       ia_assigns_submissions
    //       (UL,pk->id,fk->ia_assigns)
    //                |
    //                |
    //     ia_assigns_submissions_comment
    //(UL,pk->id,fk->ia_assigns_submissions)
    //  
    //
    // Meaning: pk->primary key field of the table
    //          fk->foreign key to link with parent
    //          nt->nested field (recursive data)
    //          CL->course level info
    //          UL->user level info
    //          files->table may have files)
    //
    //-----------------------------------------------------------


    //This function executes all the backup procedure about this mod
    function ia_backup_mods($bf,$preferences) {
        global $CFG;
        $status = true;
 
        //Iterate over ia table
        $ias = get_records ("ia","course",$preferences->backup_course,"id");
        if ($ias) {
            foreach ($ias as $ia) {
                if (backup_mod_selected($preferences,'ia',$ia->id)) {
                    $status = ia_backup_one_mod($bf,$preferences,$ia);
                 }
            }
        }
        return $status;
    }

  function ia_backup_one_mod($bf,$preferences,$ia) {
        $status = true;
        if (is_numeric($ia)) {
            $ia = get_record('ia','id',$ia);
        }

        //Start mod
        fwrite ($bf,start_tag("MOD",3,true));
        //Print choice data
        fwrite ($bf,full_tag("ID",4,false,$ia->id));
        fwrite ($bf,full_tag("MODTYPE",4,false,"ia"));
        fwrite ($bf,full_tag("NAME",4,false,$ia->name));
        fwrite ($bf,full_tag("ACTIVITY_GROUP",4,false,$ia->activity_group));
   
       // if (backup_userdata_selected($preferences,'ia',$ia->id)) {
            $status = backup_ia_assign($bf,$preferences,$ia->id);
       // }

        //End mod
        $status =fwrite ($bf,end_tag("MOD",3,true));
        return $status;
    }

    //Backup ia_assign contents (executed from ia_backup_mods)
    function backup_ia_assign($bf,$preferences,$ia) {
        global $CFG;
        $status = true;
        $ia_assigns = get_records("ia_assign","ia_id",$ia,"id");

        //If there is assigns
        if ($ia_assigns) {
            //Write start tag
            $status =fwrite ($bf,start_tag("ASSIGNS",4,true));
            //Iterate over each assign
            foreach ($ia_assigns as $ia_assign) {
                //Start 
                $status =fwrite ($bf,start_tag("ASSIGN",5,true));
                //Print  contents
                fwrite ($bf,full_tag("ID",6,false,$ia_assign->id));
                fwrite ($bf,full_tag("IA_ID",6,false,$ia_assign->ia_id));
                fwrite ($bf,full_tag("NAME",6,false,$ia_assign->name));                
                fwrite ($bf,full_tag("TYPE_ASSIGN",6,false,$ia_assign->type_assign));
                fwrite ($bf,full_tag("PROPOSITION",6,false,$ia_assign-> proposition));
                fwrite ($bf,full_tag("AUTHOR_NAME",6,false,$ia_assign-> author_name));
                fwrite ($bf,full_tag("AUTHOR_MODIFIED_NAME",6,false,$ia_assign->author_modified_name));
                //

                //search file jar in table ia_ima
                $ia_ima = get_record('ia_ima','id',$ia_assign->ia_ima_id);
                fwrite ($bf,full_tag("FILE_JAR",6,false,$ia_ima->file_jar));
                if($preferences->backup_course_files){
                   fwrite ($bf,full_tag("FILE",6,false,$ia_assign->file));
                }
                else{
                   $file_tmp=explode("/",$ia_assign->file);
                   $file_name=$file_tmp[count($file_tmp)-1];
                   fwrite ($bf,full_tag("FILE",6,false,$file_name));
                   $status=backup_ia_assign_file_assign($bf,$preferences,$ia_assign->file,$file_name);
                }

                fwrite ($bf,full_tag("GRADE",6,false,$ia_assign->grade));
                fwrite ($bf,full_tag("TIMEMODIFIED",6,false,$ia_assign->timemodified));
                fwrite ($bf,full_tag("TIMECREATED",6,false,$ia_assign->timecreated));
                fwrite ($bf,full_tag("TIMEAVAILABLE",6,false,$ia_assign->timeavailable));
                fwrite ($bf,full_tag("TIMEDUE",6,false,$ia_assign->timedue));
                fwrite ($bf,full_tag("PREVENTLATE",6,false,$ia_assign->preventlate));
                fwrite ($bf,full_tag("TEST",6,false,$ia_assign->test));
                fwrite ($bf,full_tag("SPECIAL_PARAM1",6,false,$ia_assign->special_param1));
                fwrite ($bf,full_tag("POSITION",6,false,$ia_assign->position));
                fwrite ($bf,full_tag("VISIBLE",6,false,$ia_assign->visible));
                fwrite ($bf,full_tag("MAX_EXPERIMENT",6,false,$ia_assign->max_experiment));
                fwrite ($bf,full_tag("DEPENDENCY",6,false,$ia_assign->dependency));
                fwrite ($bf,full_tag("AUTOMATIC_EVALUATE",6,false,$ia_assign->automatic_evaluate));
                fwrite ($bf,full_tag("SHOW_ANSWER",6,false,$ia_assign->show_answer));

          
                //if we've selected to backup users info, then execute backup_ia_assign_submissions
                // and backup_ia_assign_submissions_comment
                if (backup_userdata_selected($preferences,'ia',$ia_assign->ia_id)) {
                   $status = backup_ia_assign_submissions($bf,$preferences,$ia_assign->id);
                 }

                //End submission
                $status =fwrite ($bf,end_tag("ASSIGN",5,true));
            }
            //Write end tag
            $status =fwrite ($bf,end_tag("ASSIGNS",4,true));
        }
        return $status;
    }


    //Backup files
    function backup_ia_assign_file_assign($bf,$preferences,$file_from,$file_to) {

        global $CFG;

        $status = true;
        //First we check to moddata exists and create it as necessary
        //in temp/backup/$backup_code  dir

        $status = check_and_create_moddata_dir($preferences->backup_unique_code);
        $status = check_dir_exists($CFG->dataroot."/temp/backup/".$preferences->backup_unique_code."/moddata/ia/",true);
        //Now copy the assignment dir
        if ($status) {
        if (is_dir($CFG->dataroot."/".$preferences->backup_course."/")) {
            $status = backup_copy_file($CFG->dataroot."/".$preferences->backup_course."/".$file_from,
                                       $CFG->dataroot."/temp/backup/".$preferences->backup_unique_code."/moddata/ia/".$file_to);
            }
        }
        return $status;
    }



    //Backup ia_assign_submissions contents (executed from ia_backup_mods)
    function backup_ia_assign_submissions($bf,$preferences,$ia_assign) {
        global $CFG;
        $status = true;
        $ia_assign_submissions = get_records("ia_assign_submissions","ia_assign_id",$ia_assign,"id");
        //If there is submissions
        if ($ia_assign_submissions) {
            //Write start tag
            $status =fwrite ($bf,start_tag("SUBMISSIONS",6,true));
            //Iterate over each submission
            foreach ($ia_assign_submissions as $ia_submission) {
                //Start submission
                $status =fwrite ($bf,start_tag("SUBMISSION",7,true));
                //Print submission contents
                fwrite ($bf,full_tag("ID",8,false,$ia_submission->id));
                fwrite ($bf,full_tag("USER_ID",8,false,$ia_submission->user_id));
                fwrite ($bf,full_tag("TIMECREATED",8,false,$ia_submission->timecreated));
                fwrite ($bf,full_tag("TIMEMODIFIED",8,false,$ia_submission->timemodified));
                fwrite ($bf,full_tag("GRADE",8,false,$ia_submission->grade));
                fwrite ($bf,full_tag("TEACHER",8,false,$ia_submission->teacher));
                fwrite ($bf,full_tag("ANSWER",8,false,$ia_submission->answer));
                fwrite ($bf,full_tag("EXPERIMENT",8,false,$ia_submission->experiment));
                fwrite ($bf,full_tag("STATUS",8,false,$ia_submission->status));

                $status = backup_ia_assign_submissions_comment($bf,$preferences,$ia_submission->id);
               
                //End submission
                $status =fwrite ($bf,end_tag("SUBMISSION",7,true));
            }
            //Write end tag
            $status =fwrite ($bf,end_tag("SUBMISSIONS",6,true));
        }
        return $status;
    }

    function backup_ia_assign_submissions_comment($bf,$preferences,$ia_submission) {
        global $CFG;
        $status = true;
        $ia_assign_submissions_comment = get_records("ia_assign_submissions_comment ","submission_id",$ia_submission,"id");
        //If there is submissions comment
        if ($ia_assign_submissions_comment) {
            //Write start tag
            $status =fwrite ($bf,start_tag("SUBMISSIONS_COMMENTS",8,true));
            //Iterate over each submission
            foreach ($ia_assign_submissions_comment as $ia_sub_comment) {
                //Start submission
                $status =fwrite ($bf,start_tag("SUBMISSION_COMMENT",9,true));
                //Print submission contents
                fwrite ($bf,full_tag("ID",10,false,$ia_sub_comment->id));
                fwrite ($bf,full_tag("COMMENT_AUTHOR_ID",10,false,$ia_sub_comment->comment_author_id));
                fwrite ($bf,full_tag("TIMECREATED",10,false,$ia_sub_comment->timecreated));
                fwrite ($bf,full_tag("COMMENT",10,false,$ia_sub_comment->comment));
                fwrite ($bf,full_tag("RETURN_STATUS",10,false,$ia_sub_comment->return_status));
                fwrite ($bf,full_tag("RECEIVER",10,false,$ia_sub_comment->receiver));

                //End submission
                $status =fwrite ($bf,end_tag("SUBMISSION_COMMENT",9,true));
            }
            //Write end tag
            $status =fwrite ($bf,end_tag("SUBMISSIONS_COMMENTS",8,true));
        }
        return $status;
    }

        //Return an array of info (name,value)
       function ia_check_backup_mods($course,$user_data=false,$backup_unique_code,$instances=null) {
        if (!empty($instances) && is_array($instances) && count($instances)) {
            $info = array();
            foreach ($instances as $id => $instance) {
                $info += ia_check_backup_mods_instances($instance,$backup_unique_code);
            }
            return $info;
        }
    }

    ////Return an array of info (name,value)
    function ia_check_backup_mods_instances($instance,$backup_unique_code) {
         $info[$instance->id.'0'][0] = '<b>'.$instance->name.'</b>';
         $info[$instance->id.'0'][1] = get_string("submissions","ia");
         $assigns_name_submissions="";
         $assigns=ia_assign_ids_by_course ($instance->id);

         //Now, if requested, the user_data
         $tot_submissions=0;
                foreach($assigns as $assign){
                    if (!empty($instance->userdata)) {

                  //  $assigns_name_submissions.= $assign->name.'-';
                    if ($ids = ia_submission_ids_by_course ($assign->id)) {
                        $assigns_name_submissions.= '<p>'.$assign->name.'&nbsp;('.count($ids).')</p>';
                        $tot_submissions +=count($ids);
                //$info[$instance->id.'1'][$assign->id.'1'] = count($ids);
            } else {
                //$info[$instance->id.'1'][$assign->id.'1'] = 0;
                $assigns_name_submissions.= '<p>'.$assign->name.'</p>';
            }

            }else{
                //$info[$instance->id.'1'][0] = $assign->name;
                $assigns_name_submissions.= '<p>'.$assign->name.'</p>';
                //$info[$instance->id.'1'][1] = 0;
            }

             $info[$instance->id.'1'][0] = $assigns_name_submissions;
             $info[$instance->id.'1'][1]=$tot_submissions;

    }
         return $info;
    }

    //Returns an array of ia id
    function ia_ids ($course) {
        global $CFG;
        return get_records_sql ("SELECT a.id, a.course
                                 FROM {$CFG->prefix}ia a
                                 WHERE a.course = '$course'");
    }

    //Returns an array of ia entries id
    function ia_submission_ids_by_course ($assignid) {
        global $CFG;
        return get_records_sql ("SELECT s.id , s.ia_assign_id
                                 FROM {$CFG->prefix}ia_assign_submissions s
                                 WHERE s.ia_assign_id = $assignid");
    }

    //Returns an array of ia_assigns entries id
    function ia_assign_ids_by_course ($instanceid) {
        global $CFG;
        return get_records_sql ("SELECT s.id , s.ia_id, s.name, s.type_assign
                                 FROM {$CFG->prefix}ia_assign s
                                 WHERE s.ia_id = $instanceid
                                 ORDER BY `s`.`type_assign` ASC,
                                 `s`.`name` ASC");
    }

  //Returns an array of ia entries id
    function ia_entry_ids_by_instance ($instanceid) {
        global $CFG;
        return get_records_sql ("SELECT s.id , s.ia_id
                                 FROM {$CFG->prefix}ia_assign s
                                 WHERE s.ia_id = $instanceid");
    }
?>
