<?php  
/** * @description Library of functions and constants for module of activities iAssign
 *  * @author Patricia Alves Rodrigues and Leônidas O. Brandão
 *  * @version $Id: lib.php$ v 1.0 2010/09/27$
 *  * @package iAssign: Intective Assignments
 *  * @last modification date 2011/03/31
 *  *
 *  * iMatica - iMath (http://www.matematica.br)
 *  * Computer Science Dep. of IME-USP (Brazil)
 *  * */


/*
 * Adds an iAssign instance
 * @param object $ia An object from the form in mod_form.php
 * @return Fail / id number of the new instance
 */
 
function ia_add_instance($ia) {
    global $CFG;
    require_once($CFG->libdir.'/gradelib.php');
    $ia->cmidnumber='ia';
    if (!$ia->id = insert_record("ia", $ia)) 
        return false;

     $ia=(stripslashes_recursive($ia));

     $ia->grade=0;
    $grades = NULL;

     if (array_key_exists('cmidnumber', $ia)) { //it may not be always present
          $params = array('itemname'=>$ia->name, 'idnumber'=>$ia->cmidnumber);
      } else {
         $params = array('itemname'=>$ia->name);
       }
 
     if ($ia->grade > 0) {
         $params['gradetype']  = GRADE_TYPE_VALUE;
          $params['grademax']   = $ia->grade;
          $params['grademin']   = 0;
  
       } else {
          $params['gradetype']  = GRADE_TYPE_NONE;
      }
  
      if ($grades  === 'reset') {
          $params['reset'] = true;
          $grades = NULL;
       } else if (!empty($grades)) {
           // Need to calculate raw grade (Note: $grades has many forms)
           if (is_object($grades)) {
              $grades = array($grades->userid => $grades);
           } else if (array_key_exists('userid', $grades)) {
              $grades = array($grades['userid'] => $grades);
          }
          foreach ($grades as $key => $grade) {
                  $grades[$key] = $grade = (array) $grade;
              }
               $grades[$key]['rawgrade'] = ($grade['rawgrade'] * $ia->grade / 100);
           }
     
       grade_update('mod/ia', $ia->course, 'mod', 'ia', $ia->id, 0, $grades, $params);

       return $ia->id;
       
}



 
/**
 * This function will update an existing instance with new data.
 *
 * @param object $instance An object from the form in mod.html
 * @return boolean Fail
 **/

function ia_update_instance($ia) {
     global $CFG;
     $ia->id = $ia->instance;
     if (!$result = update_record("ia", $ia)) 
        return false; 

     $ia=(stripslashes_recursive($ia));
       return $result;


}




/*
 * Adds an iAssign instance
 * Create/update grade item for given interactive activities
 * @param object $ia
 * @param array $grades
 */

function ia_grade_item_update($ia, $grades) {
      global $CFG;
      require_once($CFG->libdir.'/gradelib.php');
      $params = array('itemname'=>$ia->name);
      $params['iteminstance']=$ia->id;
      $params['gradetype'] = GRADE_TYPE_VALUE;
      $params['grademax']  = $ia->grade; //need sum grades of table ia_assign
      $params['grademin']  = 0;
      grade_update('mod/ia', $ia->course, 'mod', 'ia', $ia->id, 0, $grades, $params);
 }


/**
 * Given an ID of an instance of this module,
 * this function will permanently delete the instance
 * and any data that depends on it.
 *
 * @param int $id Id of the module instance
 * @return boolean Success/Failure
 **/
function ia_delete_instance($id) {
    global $CFG;
    if (! $ia = get_record("ia", "id", "$id")) {
        return false;
    }

    ia_grade_item_delete($ia);
    $result = true;
    $ia_assign = get_records("ia_assign", "ia_id", $ia->id);
    if($ia_assign) {
        foreach($ia_assign as $assign) {
            $ia_assign_submissions= get_records("ia_assign_submissions", "ia_assign_id", $assign->id);

            if($ia_assign_submissions)
                foreach($ia_assign_submissions as $submission) {
                    delete_records('ia_assign_submissions_comment','submission_id',$submission->id);
                }
            delete_records("ia_assign_submissions", "ia_assign_id", $assign->id);
        }
    }
    delete_records("ia_assign", "ia_id", $ia->id);
    if (! delete_records("ia", "id", "$id")) {
        $result = false;
    }
    return $result;
}


function ia_grade_item_delete($ia) {
    global $CFG;
    require_once($CFG->libdir.'/gradelib.php');
   grade_update('mod/ia', $ia->course, 'mod', 'ia', $ia->id, 0, NULL, array('deleted'=>1));
}


/**
 * Return a small object with summary information about what a
 * user has done with a given particular instance of this module
 * Used for user activity reports.
 * $return->time = the time they did it
 * $return->info = a short text description
 *
 * @return null
 * @todo Finish documenting this function
 **/
function ia_user_outline($course, $user, $mod, $ia) {
    return true;
}

/**
 * Print a detailed representation of what a user has done with
 * a given particular instance of this module, for user activity reports.
 *
 * @return boolean
 * @todo Finish documenting this function
 **/
function ia_user_complete($course, $user, $mod, $ia) {
    return true;
}


function ia_get_view_actions() {
    return array('view');
}

function ia_get_post_actions() {
    return array('upload');
}


/**
 * Given a course and a time, this module should find recent activity
 * that has occurred in ia activities and print it out.
 * Return true if there was output, or false is there was none.
 *
 * @uses $CFG
 * @return boolean
 * @todo Finish documenting this function
 **/
function ia_print_recent_activity($course, $isteacher, $timestart) {
    global $CFG;

    return false;  //  True if anything was printed, otherwise false
}

/**
 * Function to be run periodically according to the moodle cron
 * This function searches for things that need to be done, such
 * as sending out mail, toggling flags etc ...
 *
 * @uses $CFG
 * @return boolean
 * @todo Finish documenting this function
 **/
function ia_cron () {
    global $CFG;

    return true;
}

/**
 * Must return an array of grades for a given instance of this module,
 * indexed by user.  It also returns a maximum allowed grade.
 *
 * Example:
 *    $return->grades = array of grades;
 *    $return->maxgrade = maximum allowed grade;
 *
 *    return $return;
 *
 * @param int $iaid ID of an instance of this module
 * @return mixed Null or object with an array of grades and with the maximum grade
 **/
function ia_grades($iaid) {
    return NULL;
}

/**
 * Must return an array of user records (all data) who are participants
 * for a given instance of ia. Must include every user involved
 * in the instance, independient of his role (student, teacher, admin...)
 * See other modules as example.
 *
 * @param int $iaid ID of an instance of this module
 * @return mixed boolean/array of students
 **/
function ia_get_participants($iaid) {
    return false;
}

/**
 * This function returns if a scale is being used by one ia
 * it it has support for grading and scales. Commented code should be
 * modified if necessary. See forum, glossary or journal modules
 * as reference.
 *
 * @param int $iaid ID of an instance of this module
 * @return mixed
 * @todo Finish documenting this function
 **/
function ia_scale_used ($iaid,$scaleid) {
    $return = false;

    //$rec = get_record("ia","id","$iaid","scale","-$scaleid");
    //
    //if (!empty($rec)  && !empty($scaleid)) {
    //    $return = true;
    //}

    return $return;
}

/**
 * Checks if scale is being used by any instance of ia.
 * This function was added in 1.9
 *
 * This is used to find out if scale used anywhere
 * @param $scaleid int
 * @return boolean True if the scale is used by any ia
 */
function ia_scale_used_anywhere($scaleid) {
    if ($scaleid and record_exists('ia', 'grade', -$scaleid)) {
        return true;
    } else {
        return false;
    }
}

/**
 * Execute post-uninstall custom actions for the module
 * This function was added in 1.9
 *
 * @return boolean true if success, false on error
 */
function ia_uninstall() {
    return true;
}

function search_iMA($enable){
    global $CFG;
    $sql="SELECT s.id, s.name
          FROM {$CFG->prefix}ia_ima s
           WHERE s.enable = $enable";
   return get_records_sql ($sql);
}

/**
 * base implementation for backing up subtype specific information
 * for one single module
 * @return boolean
 */
function backup_one_mod($bf, $preferences, $ia) {
       return true;
}

/**
 * base implementation for backing up subtype specific information
 * for one single submission
 * @return boolean
 */
function backup_one_submission($bf, $preferences, $ia, $submission) {
    return true;
}


/**
 * base implementation for restoring subtype specific information
 * for one single module
 * @return boolean
 */
function restore_one_mod($info, $restore, $ia) {
    return true;
}

/**
 * base implementation for restoring subtype specific information
 * for one single submission
 * @return boolean
 */
function restore_one_submission($info, $restore, $ia, $submission) {
    return true;
}


 function add_edit_update_ima($ima_id,$action) {
        global $USER, $CFG;
        require_once('config_form.php');
        $param = new object();
        $param->action=$action;
        $param->ima_id=$ima_id;
        $CFG->action_ima=$action;
        $CFG->ima_id=$ima_id;
        if($action=='add') {
            $title=get_string('add_ima','ia');
            $param->title=$title;
            $param->name  = "";
            $param->url= "";
            $param->description="";
            $param->extension = "";
            $param->author  = $USER->id;
            $param->file_jar  = "";
            $param->file_class  = "";
            $param->width  = 800;
            $param->heigth  = 600;
            $param->enable  = 9; // 9 - unlock 0 - hide  1 - show
            $param->timecreated  = time();
            $param->timemodified  = time();
            $param->evaluate  = 0;
            $param->parent=0;
        }elseif($action=='edit') {
            $ia_ima=get_record('ia_ima','id',$ima_id);
            $title=get_string('edit_ima','ia');
            $param->title=$title;
            $param->id  = $ia_ima->id;
            $param->name  = $ia_ima->name;
            $param->url   = $ia_ima->url;
            $param->description=$ia_ima->description;
            $param->extension = $ia_ima->extension;
            $param->author  = $ia_ima->author;
            $param->file_jar  = $ia_ima->file_jar;
            $param->file_class  = $ia_ima->file_class;
            $param->width  = $ia_ima->width;
            $param->heigth  = $ia_ima->heigth;
            $param->enable  = $ia_ima->enable;
            $param->timecreated  = $ia_ima->timecreated;;
            $param->timemodified  = time();
            $param->evaluate  = $ia_ima->evaluate;
            $param->parent=$ia_ima->parent;
        }elseif($action=='update') {
            $ia_ima=get_record('ia_ima','id',$ima_id);
            $title=get_string('update_ima','ia');
            $param->title=$title;
            $param->id  = $ia_ima->id;
            $param->name  = $ia_ima->name;
            $param->url   = $ia_ima->url;
            $param->description=$ia_ima->description;
            $param->extension = $ia_ima->extension;
            $param->author  = $ia_ima->author;
            $param->file_jar  = "";
            $param->old_file_jar  =$ia_ima->file_jar;
            $param->file_class  = $ia_ima->file_class;
            $param->width  = $ia_ima->width;
            $param->heigth  = $ia_ima->heigth;
            $param->enable  = $ia_ima->enable;
            $param->timecreated  = $ia_ima->timecreated;;
            $param->timemodified  = time();
            $param->evaluate  = $ia_ima->evaluate;
            $param->parent=$ia_ima->parent;
        }
        $mform = new mod_ima_form();
        $mform->set_data($param);
        $mform->display();
        die;
    }

  function new_ima($param) {
    global $CFG;

   // if(file_validation($_FILES)) {
        $newentry->name=$param->name;
        $newentry->url=$param->url;
        $newentry->description=$param->description;
        $newentry->extension=$param->extension;
        $newentry->file_jar="";
      //  $newentry->file_jar=$_FILES['file_jar']['name'];
        $newentry->file_class=$param->file_class;
        $newentry->width=$param->width;
        $newentry->heigth=$param->heigth;
        $newentry->enable=$param->enable;
        $newentry->timemodified=$param->timemodified;    
        $newentry->author=$param->author;
        $newentry->timecreated=$param->timecreated;
        $newentry->evaluate=$param->evaluate;
        $newentry->parent=$param->parent;

        $ia_ima_id=insert_record("ia_ima", $newentry);

        if (! $ia_ima_id) {
            error(get_string('error_add_ima', 'ia'));
        }
        else{
         redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=edit_file_jar&amp;id='.$ia_ima_id);
        }

    //}
}


function edit_ima($param) {
     global $USER, $CFG;
        $newentry->id=$param->id;
        $newentry->name=$param->name;
        $newentry->url=$param->url;
        $newentry->description=$param->description;
        $newentry->extension=$param->extension;
        $newentry->file_class=$param->file_class;
        $newentry->width=$param->width;
        $newentry->heigth=$param->heigth;
        $newentry->enable=$param->enable;
        $newentry->timemodified=$param->timemodified;    
     //   $newentry->author=$param->author;
     //   $newentry->timecreated=$param->timecreated;
        $newentry->evaluate=$param->evaluate;
     //   $newentry->parent=$param->parent;
        
        if (! update_record("ia_ima", $newentry)) {
            error(get_string('error_edit_ima', 'ia'));
        }
        else{
        // $message=$param->name.get_string('edit_ima','ia');
        // redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=ok&amp;message='.$message);
        redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=edit_file_jar&amp;id='.$param->id);
        }
}

 function update_ima($param) {
     global $USER, $CFG;
     $ia_ima=get_record('ia_ima','id',$param->id);
     
     $datecreated=date("Ymd", $ia_ima->timecreated);
     $nome_file_jar=explode('.',$ia_ima->file_jar);
     $old= $ia_ima->file_jar;
     $new= $nome_file_jar[0].$datecreated.'.'.$nome_file_jar[1];

     if(!rename_file_to_ima($old,$new)){
          $message=$param->name.get_string('error_rename_ima','ia');
          redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=ok&amp;message='.$message);
     }

     if(file_validation($_FILES)) {
     //iLM make copies present in a new record
     $newentry->name=$ia_ima->name.$datecreated;
     $newentry->url=$ia_ima->url;
     $newentry->description=$ia_ima->description;
     $newentry->extension=$ia_ima->extension;
     $newentry->file_jar=$new;
     $newentry->file_class=$ia_ima->file_class;
     $newentry->width=$ia_ima->width;
     $newentry->heigth=$ia_ima->heigth;
     $newentry->enable=0;
     $newentry->timemodified=time();
     $newentry->author=$ia_ima->author;
     $newentry->timecreated=$ia_ima->timecreated;
     $newentry->evaluate=$ia_ima->evaluate;
     $newentry->parent=$ia_ima->id;
     if (! insert_record("ia_ima", $newentry)) {
            error(get_string('error_add_ima', 'ia'));
     }
    
     
     // atualizar ima
     $updentry->id=$param->id;
     $updentry->name=$ia_ima->name;
     $updentry->url=$ia_ima->url;
     $updentry->description=$param->description;
     $updentry->extension=$param->extension;
     $updentry->file_jar=$_FILES['file_jar']['name'];
     $updentry->file_class=$param->file_class;
     $updentry->width=$param->width;
     $updentry->heigth=$param->heigth;
     $updentry->enable=$param->enable;
     $updentry->timemodified=time();
     $updentry->author=$USER->id;
     $updentry->timecreated=time();
     $updentry->evaluate=$param->evaluate;
     //$updentry->parent=$param->parent;

        if (! update_record("ia_ima", $updentry)) {
            error(get_string('error_update_ima', 'ia'));
        }
        else{
         $message=$updentry->name.get_string('update_ima','ia');
         redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=ok&amp;message='.$message);
        }
     }
    }

  function file_validation($_FILES){
       global $CFG;
       if($_FILES['file_jar']['size']==0)
            $message=get_string('empty_file','ia');
       elseif($_FILES['file_jar']['error']==4)
            $message=get_string('null_file','ia');
       elseif(copy_file_to_ima($_FILES))
             return true;
       else
            $message=get_string('error_file_jar','ia');
       redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=cancel&amp;message='.$message);
   }

function copy_file_to_ima($_FILES) {
       global $CFG;
       $filename = str_replace('\\','/', $_FILES['file_jar']['name']);
       $fullpath = $_FILES['file_jar']['tmp_name'];
       $copy_to = $CFG->dirroot.'/mod/ia/ma/'.$filename;
       if (copy($fullpath, $copy_to) and chmod ($copy_to, 0755)){
          // chmod ($copy_to, 0755);
           return true;
       }
       else{
           $message=get_string('error_file_jar_permission','ia');
           redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=cancel&amp;message='.$message);
          return false;
       }
}

function rename_file_to_ima($old,$new) {
       global $CFG;
       $nameold = $CFG->dirroot.'/mod/ia/ma/'.$old;
       $namenew = $CFG->dirroot.'/mod/ia/ma/'.$new;

       if (rename($nameold,$namenew))
          return true;
       else
          return false;
}


    function ia_process_options($mform){
       global $USER, $CFG;

       if(!empty ($mform->cancel)){
            $message=get_string('cancel','ia');
                redirect($CFG->wwwroot.'/admin/module.php?module=ia&amp;action=cancel&amp;message='.$message);
        }
        else{
            if ($mform->action=='add')
                    new_ima($mform);
            elseif ($mform->action=='edit')
                    edit_ima($mform);
            elseif ($mform->action=='update')
                    update_ima($mform);
            elseif ($mform->action=='add_file_jar')
                    upload_file_ima($mform);
            }
        die;
    }

    function upload_file_ima($mform) {
    global $USER, $CFG, $COURSE;
    $ia_ima_id = optional_param('id', NULL);
    $ia_ima = get_record('ia_ima', 'id', $mform->id);

    $file = $CFG->dirroot . '/mod/ia/ma/' . $_FILES['file_jar']['name'];

    if (!file_exists($file)) {
        $files_jar = explode(",", $ia_ima->file_jar);
        if (!empty($files_jar[0])) {
            foreach ($files_jar as $tmp) {
                if ($tmp == $_FILES['file_jar']['name'])
                    redirect($CFG->wwwroot . '/admin/module.php?module=ia&amp;action=cancel_file_jar&amp;id=' . $ia_ima->id);
            }
        }

        if (file_validation($_FILES)) {
            $updentry->id = $ia_ima->id;
            if (empty($ia_ima->file_jar))
                $updentry->file_jar = $_FILES['file_jar']['name'];
            else
                $updentry->file_jar = $ia_ima->file_jar . ',' . $_FILES['file_jar']['name'];

            if (!update_record("ia_ima", $updentry)) {
                error(get_string('error_update_ima', 'ia'));
            } else {
                redirect($CFG->wwwroot . '/admin/module.php?module=ia&amp;action=edit_file_jar&amp;id=' . $ia_ima->id);
            }
        }
    } else {
        redirect($CFG->wwwroot . '/admin/module.php?module=ia&amp;action=cancel_file_jar&amp;id=' . $ia_ima->id);
    }
}

function ia_ima_delete_file_jar($ia_ima_id,$name_file_jar){
        global $USER, $CFG, $COURSE;
        $file = $CFG->dirroot.'/mod/ia/ma/'.$name_file_jar;

        if (unlink($file)){
            $ia_ima=get_record('ia_ima','id',$ia_ima_id);
            $files_jar=explode(",",$ia_ima->file_jar);
            $tmp=array();
            foreach ($files_jar as $file_jar){
                if($file_jar!=$name_file_jar)
                    $tmp[]=$file_jar;
            }
            $files_jar_new=implode(",",$tmp);

            $updentry->id=$ia_ima->id;
            $updentry->file_jar=$files_jar_new;

            $tmp_ia_ima=update_record("ia_ima", $updentry);
            if (!$tmp_ia_ima)
               error(get_string('error_update_ima', 'ia'));
             else
               redirect($CFG->wwwroot . '/admin/module.php?module=ia&amp;action=edit_file_jar&amp;id=' . $ia_ima_id,get_string('delete_confirm','ia'),1000);
        }
        else{
             redirect($CFG->wwwroot . '/admin/module.php?module=ia&amp;action=edit_file_jar&amp;id=' . $ia_ima_id,get_string('error_cancel_delete','ia'),1000);
        }
    }

    function ia_ima_show($ia_ima_id) {
    global $USER, $CFG, $COURSE;

        $tmps=get_records_sql("SELECT s.file_jar
        FROM {$CFG->prefix}ia_ima s
        WHERE s.parent = 0");

        $filejars= "";
        foreach ($tmps as $tmp)
            $filejars .="'".$tmp->file_jar."',";

        //-----
         ///javascripts
         $code_javascript="
             <script type='text/javascript'>
             <!--
             function search_filejar(fullfilejar){
               var i;
               var tmp=fullfilejar.split('/');
               var filejar=tmp[tmp.length-1];
               var filejars = new Array(";
               $code_javascript .=$filejars."'');".chr(13);
               $code_javascript .="
               for (i=0;i<filejars.length;i++){

                   if(filejars[i].toLowerCase()==fullfilejar.toLowerCase()){
                      document.forms['new_file'].file_jar.value='';
                      confirm('".get_string('invalid_filejar_ima', 'ia')." '+fullfilejar+'!');
                    }
                }
                }
               --></script>";

    $test = optional_param('test', NULL);
    if ($test == 'confirm') {
        $updentry->id = $ia_ima_id;
        $updentry->enable = 1;
        if (!update_record("ia_ima", $updentry))
            error(get_string('error_update_ima', 'ia'));
        else{
           $test = NULL;
        }
    }

    $ia_ima = get_records_sql("SELECT s.*
              FROM {$CFG->prefix}ia_ima s
              WHERE s.id = '$ia_ima_id'");

    $struploadafile = get_string('uploadafile');
    $maxbytes = get_max_upload_file_size($CFG->maxbytes);

    $action = '';
    $icon_delete = '<img src="' . $CFG->wwwroot . '/mod/ia/icon/delete1.gif" />';
    $icon_confirm = '<img src="' . $CFG->wwwroot . '/mod/ia/icon/confirm.gif" />';
    $icon_edit = '<img src="' . $CFG->wwwroot . '/mod/ia/icon/edit.gif" />';
    $icon_home = '<img src="' . $CFG->wwwroot . '/mod/ia/icon/home.gif" />';
    $icon_return = '<img src="' . $CFG->wwwroot . '/mod/ia/icon/return.gif" />';

    $str = "";
    $str =$code_javascript;
    $str.= '<table id="outlinetable" class="generaltable boxaligncenter" cellpadding="5" width="100%" >' . chr(13);
    $str .='<tr><td class=\'cell c0 actvity\' align=left>';
    $str.='&nbsp;<a href="' . $CFG->wwwroot . '/admin/module.php?module=ia&amp;action=edit&amp;ima_id=' . $ia_ima_id . '">' . $icon_edit . '&nbsp;' . get_string('edit_ima', 'ia') . '</a>';
    $str .='<td></td>';
    $str.='<td align=right><a href="' . $CFG->wwwroot . '/admin/module.php?module=ia">' . $icon_return . '&nbsp;' . get_string('return_config_ima', 'ia') . '</a></td>';
    $str .='</tr>';
    $str.= '<tr><th colspan=3 class="header c1">' . get_string('info_ima', 'ia') . '</th></tr>' . chr(13);

    if ($ia_ima) {
        foreach ($ia_ima as $ima) {
            $ia_assign = get_records('ia_assign', 'ia_ima_id', $ima->id);
            if ($ia_assign)
                $total = count($ia_assign);
            else
                $total=0;
            $str .='<tr>';
            $str.= '<td colspan=2 class=\'cell c0 actvity\' width=60%><strong>' . get_string('name_ima', 'ia') . ':</strong>&nbsp;' . $ima->name . '</td>' . chr(13);
            $str.= '<td class=\'cell c0 actvity\' ><strong>' . get_string('activities', 'ia') . ':</strong>&nbsp;' . $total . '</td>' . chr(13);
            $str .='</tr>';
            $str .='<tr><td colspan=3>';
            $str.= '<table width="100%">';
            $str .='<tr><td><strong>' . get_string('description', 'ia') . ':</strong>&nbsp;' . $ima->description . '</td></tr>';
            $str .='<tr><td ><strong>' . get_string('file_class', 'ia') . ':</strong>&nbsp;' . $ima->file_class . '</td>';
            $str .='<td colspan=2><strong>' . get_string('url_ima', 'ia') . '</strong>&nbsp;<a href="' . $ima->url .'">' . $ima->url . '</a></td></tr>';
            $str .='<tr><td width="50%"><strong>' . get_string('extension', 'ia') . ':</strong>&nbsp;' . $ima->extension . '</td>';
            $str .='<td width="50%"><strong>' . get_string('width', 'ia') . ':</strong>&nbsp;' . $ima->width;
            $str .='&nbsp;&nbsp;<strong>' . get_string('heigth', 'ia') . ':</strong>&nbsp;' . $ima->heigth . '</td></tr>';
            if ($ima->evaluate == 1)
                $evaluate = get_string('yes', 'ia');
            else
                $evaluate=get_string('no', 'ia');

            $str .='<tr><td width="50%"><strong>' . get_string('evaluate', 'ia') . ':</strong>&nbsp;' . $evaluate . '</td>';
            if ($ima->enable == 1)
                $enable = get_string('yes', 'ia');
            else
                $enable=get_string('no', 'ia');
            $str .='<td width="50%"><strong>' . get_string('enable', 'ia') . ':</strong>&nbsp;' . $enable . '</td></tr>';
            $str.= '</table>';
            $str .='</td></tr>';
        }

        if ($test != "ima") {
            $str.= '<tr><th colspan=3 class="header c1">' . get_string('files_jar_ima', 'ia') . '</th></tr>' . chr(13);

            $files_jar = explode(",", $ima->file_jar);
            if (empty($files_jar[0])) {
                $str .='<tr><td colspan=3>' . get_string('null_file', 'ia') . '</td></tr>';
            } else {
                foreach ($files_jar as $tmp) {
                    $link_delete = '&nbsp;<a href="' . $CFG->wwwroot . '/admin/module.php?module=ia&amp;action=delete_file_jar&amp;id=' . $ima->id . '&amp;name_file_jar=' . $tmp . '">' . $icon_delete . '</a>';
                    $str .='<tr><td colspan=3>';
                    if ($ima->enable == 0 or $ima->enable == 1)
                        $str .= $tmp . '&nbsp;';
                    else
                        $str .= $tmp . '&nbsp;' . $link_delete;
                    $str .='</td></tr>';
                }
            }

            if ($ima->enable == 9) {
                $str .='<tr class=\'cell c0 actvity\'><td  colspan=3 align=center>'. chr(13);
                $str .='<form name="new_file" enctype="multipart/form-data" method="post" action="module.php?module=ia">'. chr(13);
                $str .= '<input type="hidden" name="id" value="' . $ima->id . '" />'. chr(13);
                $str .= '<input type="hidden" name="sesskey" value="' . sesskey() . '" />'. chr(13);
                $str .= '<input type="hidden" name="action" value="add_file_jar" />'. chr(13);
                $str .= '<input type="hidden" name="MAX_FILE_SIZE" value="' . $maxbytes . '">'. chr(13);
                $str .= get_string('add_file_jar', 'ia') . '&nbsp;<input name="file_jar" type="file" onchange="search_filejar(this.value)"/>'. chr(13);
                $str .='&nbsp;(' . get_string('maxsize', 'ia') . '&nbsp;' . display_size($maxbytes) . ')&nbsp;'. chr(13);
                $str .= '<p><input type="submit" value="' . get_string('submit', 'ia') . '" /></p>'. chr(13);
                $str .= '</form>';

               // $mform->addElement('file', 'file_jar', get_string('new_file_jar', 'ia'),array('onchange'=>'search_filejar(this.value);'));

                $str .='</td></tr>';
            }
           if (!empty($files_jar[0])) {
            $str .='<tr class=\'cell c0 actvity\'><td colspan=3 align=center>';
            $str.='<a href="' . $CFG->wwwroot . '/admin/module.php?module=ia&amp;test=ima&amp;action=edit_file_jar&amp;id=' . $ima->id . '">' . get_string('test_lms', 'ia') . '</a>';
           }
        } elseif(!empty ($ima->file_jar)){
            $lang = substr(current_language(), 0, 2);
            $str .= '<tr><th colspan=3 class="header c1">' . get_string('area_test_lms', 'ia') . '</th></tr>' . chr(13);
            $str .='<tr class=\'cell c0 actvity\'><td  colspan=3 align=center>';

            $str.= '
            <applet name="eMA" codebase="' . $CFG->wwwroot . '/mod/ia/ma/" code="' . $ima->file_class . '" archive="' . $ima->file_jar . '" width="' . $ima->width . '" height="' . $ima->heigth . '" vspace=10 hspace=10>
            <param name="MA_PARAM_notSEND" value="true"/>
            <param name="lang" value="' . $lang . '"/>
            </applet> <br/>';

            if ($ima->enable == 9) {
                $str .='<tr class=\'cell c0 actvity\'>';
                $str .='<td align=center><a href="' . $CFG->wwwroot . '/admin/module.php?module=ia&amp;test=confirm&amp;action=edit_file_jar&amp;id=' . $ima->id . '">' . $icon_confirm . '&nbsp;' . get_string('confirm_lms', 'ia') . '</a></td>';
                $str .='<td align=center><a href="' . $CFG->wwwroot . '/admin/module.php?module=ia&amp;action=edit_file_jar&amp;id=' . $ima->id . '">' . $icon_return . '&nbsp;' . get_string('no_confirm_lms', 'ia') . '</a></td>';
                $str .= '</tr>';
              }
         }else{

             $str .='<tr class=\'cell c0 actvity\'>';
             $str .='<td colspan=2 align=center>' . get_string('null_file', 'ia') . '</td>';
             $str .='<td align=center><a href="' . $CFG->wwwroot . '/admin/module.php?module=ia&amp;action=edit_file_jar&amp;id=' . $ima->id . '">' . $icon_return . '&nbsp;' . get_string('return', 'ia') . '</a></td>';
             $str .= '</tr>';

         }
        $str .= '</td></tr>';
        
    }

    $str .= '</table>';
    $str .= '<br><br>';
    echo $str;
}
 
?>
